@@ -3,7 +3,6 @@ from django.utils.translation import ugettext as _
 
 from cms.plugin_base import CMSPluginBase
 from cms.plugin_pool import plugin_pool
-from filer.models.imagemodels import Image
 
 from image_gallery.models import GalleryPlugin
 
@@ -11,20 +10,12 @@ from image_gallery.models import GalleryPlugin
 class CMSGalleryPlugin(CMSPluginBase):
     model = GalleryPlugin
     name = _('Filer Gallery')
-    render_template = 'image_gallery/gallery.html'
-
-    def get_folder_images(self, folder, user):
-        qs_files = folder.files.instance_of(Image)
-        if user.is_staff:
-            return qs_files
-        else:
-            return qs_files.filter(is_public=True)
+    render_template = 'image_gallery/partials/gallery.html'
 
     def render(self, context, instance, placeholder):
         context.update({
             'gallery': instance.gallery,
-            'images': self.get_folder_images(instance.gallery.folder,
-                                             context['request'].user),
+            'images': instance.gallery.get_folder_images(),
             'placeholder': placeholder,
         })
         return context
