@@ -1,4 +1,6 @@
 """Models for the ``image_gallery`` app."""
+from itertools import chain
+
 from django.core.urlresolvers import reverse
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -18,6 +20,7 @@ class Gallery(models.Model):
     :location: Location of the gallery items.
     :description: Description of the gallery.
     :folder: Linked folder of the filer app.
+    :is_published: True if the Gallery is published or not.
 
     """
     category = models.ForeignKey(
@@ -51,6 +54,11 @@ class Gallery(models.Model):
         verbose_name=_('Folder'),
     )
 
+    is_published = models.BooleanField(
+        verbose_name=_('Is published'),
+        default=False,
+    )
+
     def __unicode__(self):
         return '{0}'.format(self.title)
 
@@ -62,6 +70,20 @@ class Gallery(models.Model):
         qs_files = self.folder.files.instance_of(Image)
         return qs_files.filter(is_public=True)
 
+    def get_folder_image_list(self):
+        """
+        Returns a list of images, which have been placed in this folder.
+
+        They are first sorted by name, followed by those without name, sorted
+        by file name.
+
+        """
+        qs_files = self.folder.files.instance_of(Image)
+        qs_files = qs_files.filter(is_public=True)
+        return list(chain(
+            qs_files.exclude(name='').order_by('name'),
+            qs_files.filter(name='').order_by('file')))
+
 
 class GalleryCategory(models.Model):
     """
